@@ -85,7 +85,15 @@ def runList(*taskList):
         else:
             printcolor.set_cmd_text_color(printcolor.FOREGROUND_BLACK | printcolor.BACKGROUND_DARKGREEN)
 
-        b.info(f"任务结束 warning({b.countLogWarning}) error({b.countLogError}) critical({b.countLogCritical})")
+        msgAry = ["任务结束"]
+        if b.countLogCritical:
+            msgAry.append("critical({b.countLogCritical})")
+        if b.countLogError:
+            msgAry.append("error({b.countLogError})")
+        if b.countLogWarning:
+            msgAry.append("warning({b.countLogWarning})")
+
+        b.info(" ".join(msgAry))
         passTime = str(datetime.datetime.now() - startTime)
         if passTime.startswith("0:"):
             passTime = "0" + passTime
